@@ -263,6 +263,11 @@ def load_clr(finder, module):
     )
 
 
+def load_cryptography_hazmat_bindings__openssl(finder, module):
+    """the cryptography module requires the cffi module"""
+    finder.IncludeModule("cffi")
+
+
 def load_cryptography_hazmat_bindings__padding(finder, module):
     """the cryptography module requires the _cffi_backend module (loaded implicitly)"""
     finder.IncludeModule("_cffi_backend")
@@ -459,8 +464,8 @@ def load_glib(finder, module):
 
 
 def load_google_cloud_storage(finder, module):
-    """the google.cloud.storage package always uses _http module."""
-    finder.IncludeModule("google.cloud._http")
+    """the google.cloud.storage package always uses the parent module."""
+    finder.IncludePackage("google.cloud")
 
 
 def load_gtk__gtk(finder, module):
@@ -533,6 +538,7 @@ def _get_data_path():
                 break
         module.code = rebuild_code_object(co, constants=constants)
     finder.ExcludeModule("matplotlib.tests")
+    finder.IncludePackage("matplotlib")
 
 
 def load_numpy(finder, module):
